	OPTION EXPLICIT
	OPTION DEFAULT NONE
	CPU 48
	GOTO TestSuite

'************************************************************************************* 
' 
' Peter Mather
' 
' 1.2.0
' 2015-30-6 
' 
'
' 1.1 Scrolling added when optimised pinout used
' 1.1.1 Further performance improvements
' 1.2.0 Specific 44-pin optimised variant removed, all functions available with any pin allocation
'       Changed triangle drawing CFunction to accept an array of coordinates
'
' Graphics library with drivers for S6D80164 display 
' 8-bit parallel output from Micromite MX170 - flexible pinout
'
' drawing primitives assume a graphics display where top left is point 0, 0
' function calls are as compatible as possible with the in-built graphics routines as documented for version 4.7
'
' Define which pins are used to interface with the display
' Call S6D8.PinDefs BEFORE calling anything else in S6D8
' Sub S6D8.PinDefs(D0,D1,D2,D3,D4,D5,D6,D7,RS,RD,WR,RST)
'	  D0-D7 Pins used for DB8-DB15
' 	  D0, any valid pin
'     D1, any valid pin
'     D2, any valid pin
'     D3, any valid pin
'     D4, any valid pin
'     D5, any valid pin
'     D6, any valid pin
' 	  D7, any valid pin
'	    RS Pin used for RS, any valid pin
'     RD Pin used for RD, any valid pin or zero if connected to ground
'     WR Pin used for WR, any valid pin
'     RST Pin used to generate Reset signal to display controller
'
'initialise display:
'SUB S6D8.init
'     no parameters
'
'
' clear screen: sub S6D8.CLS(colour)
'    clear the screen to the colour specified
'    if the colour is omitted the screen is cleared to black
'
' set screen orientation: sub S6D8.ROTATE(orientation)
'    valid values are PORTRAIT:0, RPORTRAIT:1, LANDSCAPE:2, RLANDSCAPE:3
'
' plot PIXEL: sub S6D8.PIXEL(x, y, c) 
'    x, y coordinates of PIXEL, colour
'
' draw circle: sub S6D8.CIRCLE(x, y, r, c, f)
'    x, y coordinates of centre, radius, colour of outline, colour to fill
'    if colour to fill is omitted an outline only is drawn
'    to fill with black use the special function S6D8.BLACK() as the colour
'    to generate a circle in a single solid colour use the same colour for the outline and the fill
'
' draw triangle:  sub S6D8.TRIANGLE(x0, y0, x1, y1, 	x2, y2, c, f) 
'    three coordinate pairs, colour of outline, colour to fill
'    if colour to fill is omitted an outline only is drawn
'    to fill with black use the special function S6D8.BLACK() as the colour
'    to generate a triangle in a single solid colour use the same colour for the outline and the fill
'
' print text: sub S6D8.TEXT(xx0, yy0, text$, font, size, forecolour, backcolour)
'    x, y coordinates of top left of first character, font number, text string, size, c,  foreground colour,  background colour
'    if the background colour is omitted black will be used
'
' print bitmap: sub S6D8.BITMAP(x, y, bitmap, width, height, scale, forecolour, backcolour)
'    x, y coordinates of top left of the bitmap, bitmap, size, character orientation,  foreground colour,  background colour
'    the bitmap must be specifed as an array of integers
'    to output bitmap contained within a single integer use array size 1 and allocate the bimap to element 0
'
' draw line: sub S6D8.LINE(x0, y0, x1, y1, colour) 
'    x, y of start line, x, y of end line, foreground colour,  background colour
'
' draw rectangle: sub S6D8.BOX(x, y, w, h, c, f)
'    x, y coordinate of top left, width, height, colour of outline, colour to fill
'    if colour to fill is omitted an outline only is drawn
'    to fill with black use the special function S6D8.BLACK() as the colour
'    to generate a rectangle in a single solid colour use the same colour for the outline and the fill
'
' draw rounded rectangle: sub S6D8.RBOX(x, y, w, h, r, c, f)
'    x, y coordinates of top left, width, height, radius of corner, colour of outline, colour to fill
'    if colour to fill is omitted an outline only is drawn
'    to fill with black use the special function S6D8.BLACK() as the colour
'    to generate a rounded rectangle in a single solid colour use the same colour for the outline and the fill
'
' screen horizontal resolution in default orientation:  S6D8.MM.HRES.DEFAULT
' screen vertical resolution in default orientation:  S6D8.MM.VRES.DEFAULT
' screen horizontal resolution in current orientation:  S6D8.MM.HRES
' screen vertical resolution in current orientation:  S6D8.MM.VRES
'
'

sub S6D8.init

	'Global variables
  DIM integer i, S6D8.x0(1),S6D8.x1(1),S6D8.x2(1),S6D8.y0(1),S6D8.y1(1),S6D8.y2(1),S6D8.col(1)
	'Command codes for S6D8 CFunction
	DIM INTEGER S6D8.pix=0, S6D8.ffr=1, S6D8.filltri=2, S6D8.drawline=3, S6D8.wr=5
	DIM INTEGER S6D8.fpstring=7, S6D8.fcirch=8, S6D8.circh=9, S6D8.Bits=10, S6D8.scrolled=11, S6D8.initialise=12

	'Orientation codes
	DIM INTEGER LANDSCAPE=2, RLANDSCAPE=3, PORTRAIT=0, RPORTRAIT=1
	
	DIM INTEGER S6D8.MM.HRES.DEFAULT, S6D8.MM.VRES.DEFAULT, S6D8.MM.HRES, S6D8.MM.VRES
  S6D8.MM.HRES.DEFAULT=176: S6D8.MM.VRES.DEFAULT=220
	S6D8.VAR(S6D8.wi)=S6D8.MM.HRES.DEFAULT :  S6D8.VAR(S6D8.ht)=S6D8.MM.VRES.DEFAULT
	S6D8.VAR(S6D8.PORTS)=S6D8(S6D8.initialise,S6D8.VAR())
	
	'Reset the display controller
	PIN(S6D8.VAR(S6D8.RST_I))=1:  SETPIN S6D8.VAR(S6D8.RST_I),DOUT
	PAUSE 100
	PIN(S6D8.VAR(S6D8.RST_I))=0
	PAUSE 100
	PIN(S6D8.VAR(S6D8.RST_I))=1
	PAUSE 100
    S6D8.cfg(&H11,&H001A) :   S6D8.cfg(&H12,&H3121) :  S6D8.cfg(&H13,&H006C)
    S6D8.cfg(&H14,&H4249) :   S6D8.cfg(&H10,&H0800) :  pause 10
    S6D8.cfg(&H11,&H011A) :    pause 10
    S6D8.cfg(&H11,&H031A) :    pause 10
    S6D8.cfg(&H11,&H071A) :    pause 10
    S6D8.cfg(&H11,&H0F1A) :    pause 10
    S6D8.cfg(&H11,&H0F3A) :    pause 30
    S6D8.cfg(&H01,&H011C) :    S6D8.cfg(&H02,&H0100) :    S6D8.cfg(&H03,&H1030)
    S6D8.cfg(&H07,&H0000) :    S6D8.cfg(&H08,&H0808) :    S6D8.cfg(&H0B,&H1100)
    S6D8.cfg(&H0C,&H0000) :    S6D8.cfg(&H0F,&H1401) :    S6D8.cfg(&H15,&H0000)
    S6D8.cfg(&H20,&H0000) :    S6D8.cfg(&H21,&H0000) :    S6D8.cfg(&H36,&H00AF)
    S6D8.cfg(&H37,&H0000) :    S6D8.cfg(&H38,&H00DB) :    S6D8.cfg(&H39,&H0000)
    S6D8.cfg(&H0F,&H0B01) :    S6D8.cfg(&H07,&H0016) :    S6D8.cfg(&H07,&H0017) :  pause 50
    S6D8.rotate(portrait)
end sub
'
' Set up the pin definitions
' Call S6D8.PinDefs BEFORE calling anything else in S6D8 
' RS, any valid pin
' RD, any valid pin, set to zero if tied high, scroll functionality not available if zero
' WR, any valid pin
' D0, any valid pin
' D1, any valid pin
' D2, any valid pin
' D3, any valid pin
' D4, any valid pin
' D5, any valid pin
' D6, any valid pin
' D7, any valid pin
' RST: define the pin to use for REST, any valid pin
'
SUB S6D8.PinDefs(D0%,D1%,D2%,D3%,D4%,D5%,D6%,D7%,RS%,RD%,WR%,RST%)

	'Holds Parameters for use in the Cfunction
	DIM INTEGER S6D8.VAR(21) 
	
	'Subscripts in S6D8.VAR for each parameter
	DIM INTEGER S6D8.Default_Rotation=0 'default screen orientation for this display type, in this case PORTRAIT
	DIM INTEGER S6D8.wi=0,S6D8.ht=1,S6D8.rot=2,S6D8.nr=3,S6D8.X=4,S6D8.Y=5,S6D8.seed=6  
	DIM INTEGER S6D8.RS_I=7, S6D8.WR_I=8
	
	'Subscripts for the 16 bit data bus 
  DIM integer S6D8.RS_I=7, S6D8.WR_I=8
  DIM integer S6D8.DB0_I=9, S6D8.DB1_I=10, S6D8.DB2_I=11, S6D8.DB3_I=12
  DIM integer S6D8.DB4_I=13, S6D8.DB5_I=14, S6D8.DB6_I=15, S6D8.DB7_I=16
  DIM integer S6D8.RD_I=17,S6D8.PORTS=18,S6D8.RST_I=19, S6D8.SCROLL_I=20
 	pin(RST%)=1:  SETPIN RST%,dout	
	'the CFunction will execute the SETPIN commands itself
	S6D8.VAR(S6D8.RST_I)=RST% : 
	S6D8.VAR(S6D8.RS_I)=RS%     :  S6D8.VAR(S6D8.WR_I)=WR%    :  S6D8.VAR(S6D8.RD_I)=RD%
	S6D8.VAR(S6D8.DB0_I)=D0%    :  S6D8.VAR(S6D8.DB1_I)=D1%   :  S6D8.VAR(S6D8.DB2_I)=D2%
	S6D8.VAR(S6D8.DB3_I)=D3%    :  S6D8.VAR(S6D8.DB4_I)=D4%   :  S6D8.VAR(S6D8.DB5_I)=D5%
	S6D8.VAR(S6D8.DB6_I)=D6%    :  S6D8.VAR(S6D8.DB7_I)=D7%  
	
END SUB
'
sub S6D8.cfg(r%, d%)
  local i%
  i%=S6D8(S6D8.wr, r%, d%, S6D8.VAR())
end sub
'
'
' Generic drawing routines
'
'
sub S6D8.CLS(c%)
  local integer j,i=S6D8.VAR(S6D8.rot)
  S6D8.VAR(S6D8.rot)=PORTRAIT
  j=S6D8(S6D8.ffr, c%, 0,0,S6D8.VAR(S6D8.wi),S6D8.VAR(S6D8.ht), S6D8.VAR())
  S6D8.VAR(S6D8.rot)=i
end sub
'
sub S6D8.CIRCLE(x%, y%, r%, c%, f%)
  local i%
  if(f%) then 
    i%=S6D8(S6D8.ffr, f%, x%, y%-r%, 1, 2*r%+1,  S6D8.VAR())
    i%=S6D8(S6D8.fcircH, x%, y%, r%, 3, 0, f%, S6D8.VAR())
  endif
  if(f%<>c%) then i%=S6D8(S6D8.circh, c%, x%, y%, r%, 31, S6D8.VAR())
end sub
 '
function S6D8.black()as integer
   S6D8.black=&H8000000000000000
end function
'
sub S6D8.PIXEL(x as integer, y as integer,  c as integer) 
  local i%=S6D8(S6D8.pix, c, x, y, S6D8.VAR())
end sub
 '
sub S6D8.TRIANGLE(x0 as integer, y0 as integer, x1 as integer, y1 as integer, x2 as integer, y2 as integer, c as integer, f as integer)
  if(f) then i=S6D8(S6D8.filltri, 1, x0,y0,x1,y1,x2,y2,c,S6D8.VAR())
  if(f<>c) then
     S6D8.LINE(x0, y0, x1, y1, c)
     S6D8.LINE(x1, y1, x2, y2, c)
     S6D8.LINE(x2, y2, x0, y0, c)
  endif
end sub
'
sub S6D8.TEXT(x%, y%, text$, font%, sz%, c%, f%) 
  local j%=font% and 1
  local integer i=S6D8(S6D8.fpstring,j%,x%,y%,sz%,c%,f%,S6D8.VAR(),text$)
end sub
'
sub S6D8.LINE(x0%, y0%, x1%, y1%, c%)
   local i%=S6D8(S6D8.drawline, c%, x0%, y0%, x1%, y1%,  S6D8.VAR())
end sub
'
sub S6D8.BOX(x as integer, y as integer, w as integer, h as integer, c as integer, f as integer)
  local integer a, i
  if(f) then i=S6D8(S6D8.ffr, f, x, y, w, h,  S6D8.VAR()) 
  if(f<>c) then
     i=S6D8(S6D8.ffr, c, x, y, w, 1,  S6D8.VAR()) 
     a=y+h-1
     i=S6D8(S6D8.ffr, c, x, a, w, 1,  S6D8.VAR()) 
     i=S6D8(S6D8.ffr, c, x, y, 1, h,  S6D8.VAR()) 
     a=x+w-1
     i=S6D8(S6D8.ffr, c, a, y, 1, h,  S6D8.VAR()) 
  endif
end sub
'
sub S6D8.BITMAP(x%, y%, array%(), w%, h%, sz%, c%, f%)
  local i%=S6D8(S6D8.Bits, x%,y%,w%,h%,sz%,c%,f%,array%(),S6D8.VAR())  
end sub
'
sub S6D8.RBOX(x as integer, y as integer, w as integer, h as integer, r as integer, c as integer, f as integer)
  local integer i
  if(f) then
	  i=S6D8(S6D8.ffr, f, x+r, y, w-2*r, h,  S6D8.VAR()) 
	  i=S6D8(S6D8.fcircH,x+w-r-1, y+r, r, 1, h-2*r-1, f, S6D8.VAR())
	  i=S6D8(S6D8.fcircH,x+r, y+r, r, 2, h-2*r-1, f, S6D8.VAR())
  endif
  if(f<>c) then
	  i=S6D8(S6D8.ffr, c, x+r, y, w-2*r, 1,  S6D8.VAR()) 
	  i=S6D8(S6D8.ffr, c, x+r, y+h-1, w-2*r, 1,  S6D8.VAR()) 
	  i=S6D8(S6D8.ffr, c, x, y+r, 1, h-2*r,  S6D8.VAR()) 
	  i=S6D8(S6D8.ffr, c, x+w-1, y+r, 1, h-2*r,  S6D8.VAR()) 
	  i=S6D8(S6D8.circh, c, x+r, y+r, r, 1,S6D8.VAR())
	  i=S6D8(S6D8.circh,  c, x+w-r-1, y+r, r, 2,S6D8.VAR())
	  i=S6D8(S6D8.circh,  c, x+w-r-1, y+h-r-1, r, 4,S6D8.VAR())
	  i=S6D8(S6D8.circh,  c, x+r, y+h-r-1, r, 8,S6D8.VAR())
  endif
end sub
'
SUB S6D8.SCROLL(x%, y%, w%, h%)
   IF S6D8.VAR(S6D8.RD_I) THEN
      LOCAL i%=S6D8(S6D8.SCROLLed,x%,y%,w%,h%,S6D8.VAR())
   ENDIF
END SUB
'
sub S6D8.ROTATE(x%) 'sets screen rotation: 0=PORTRAIT, 1=RPORTRAIT, 2=LANDSCAPE, 3-RLANDSCAPE
    S6D8.VAR(S6D8.rot)=(x% and 3)
    local o% = &H1030
    select case x%
        case portrait
		     S6D8.MM.VRES=S6D8.MM.VRES.DEFAULT
		     S6D8.MM.HRES=S6D8.MM.HRES.DEFAULT
         case rportrait
		       S6D8.MM.VRES=S6D8.MM.VRES.DEFAULT
		       S6D8.MM.HRES=S6D8.MM.HRES.DEFAULT
           o% = &H1000
         case landscape
		       S6D8.MM.VRES=S6D8.MM.HRES.DEFAULT
		       S6D8.MM.HRES=S6D8.MM.VRES.DEFAULT
           o% = &H1028
         case rlandscape
		       S6D8.MM.VRES=S6D8.MM.HRES.DEFAULT
		       S6D8.MM.HRES=S6D8.MM.VRES.DEFAULT
           o% = &H1018
    end select
    S6D8.cfg(&H03,o%) ' set address mode
end sub
'
CFunction S6D8
	00000652
	'psend
	8ca20090 00043a03 24a60030 8ca30030 00e31826 aca70030 00043fc3 acc70004 
	30670001 10e00005 30670002 8c470044 8c480024 ace80000 30670002 10e00005 
	30670004 8c470048 8c480028 ace80000 30670004 10e00005 30670008 8c47004c 
	8c48002c ace80000 30670008 10e00005 30670010 8c470050 8c480030 ace80000 
	30670010 10e00005 30670020 8c470054 8c480034 ace80000 30670020 10e00005 
	30670040 8c470058 8c480038 ace80000 30670040 50e00005 30630080 8c47005c 
	8c48003c ace80000 30630080 50600005 8c430010 8c430060 8c470040 ac670000 
	8c430010 8c470014 ac670000 8c43000c 8c470014 ac670000 308400ff 8ca30030 
	00831826 aca40030 30640001 10800004 acc00004 8c440044 8c450024 ac850000 
	30640002 10800005 30640004 8c440048 8c450028 ac850000 30640004 10800005 
	30640008 8c44004c 8c45002c ac850000 30640008 10800005 30640010 8c440050 
	8c450030 ac850000 30640010 10800005 30640020 8c440054 8c450034 ac850000 
	30640020 10800005 30640040 8c440058 8c450038 ac850000 30640040 50800005 
	30630080 8c44005c 8c45003c ac850000 30630080 50600005 8c430010 8c430060 
	8c440040 ac640000 8c430010 8c440014 ac640000 8c43000c 8c420014 ac620000 
	03e00008 00000000 

	'writeRegister
	27bdffe0 afbf001c afb20018 afb10014 afb00010 00a09021 00c08821 8cd00090 
	8e020004 8e030008 ac430000 00c02821 0411FF79 00000000 8e020000 8e030008 
	ac430000 02402021 02202821 0411FF72 00000000 8fbf001c 8fb20018 8fb10014 
	8fb00010 03e00008 27bd0020 

	'initdisplay
	27bdffc8 afbf0034 afb70030 afb6002c afb50028 afb40024 afb30020 afb2001c 
	afb10018 afb00014 0080a021 3c109d00 8e02003c 0040f809 24040200 0040b821 
	8e02003c 0040f809 24040294 ae8200a0 000217c3 ae8200a4 8e020024 8e840038 
	0040f809 24050006 aee20000 8e020024 8e840038 0040f809 24050005 aee20004 
	8e020028 0040f809 8e840038 24110001 00511004 aee20008 8e020024 8e840040 
	0040f809 24050006 aee2000c 8e020024 8e840040 0040f809 24050005 aee20010 
	8e020028 0040f809 8e840040 00511004 aee20014 8e840088 8e82008c 00821025 
	1040000a 02809821 8e020010 24050008 0040f809 00003021 8e02001c 8e840088 
	0040f809 24050006 02809821 26f10024 26f50044 02809021 3c109d00 24160001 
	8e020028 0040f809 8e440048 00561004 ae220000 8e020024 8e440048 0040f809 
	2405ffff ae220040 8e020024 8e440048 0040f809 24050007 ae220020 8e020024 
	8e440048 0040f809 00002821 ae220060 26310004 1635ffea 26520008 24110007 
	3c109d00 24120011 8e020010 8e640038 24050008 0040f809 00003021 8e02001c 
	8e640038 0040f809 24050005 26310001 1632fff5 26730008 3c109d00 8e02001c 
	8e840038 0040f809 24050006 8e02001c 8e840040 0040f809 24050006 00001021 
	00001821 ae820030 ae830034 02e01021 00001821 8fbf0034 8fb70030 8fb6002c 
	8fb50028 8fb40024 8fb30020 8fb2001c 8fb10018 8fb00014 03e00008 27bd0038 

	'defineregion
	27bdffd0 afbf002c afb60028 afb50024 afb40020 afb3001c afb20018 afb10014 
	afb00010 8fb00040 2483ffff 00661821 24a6ffff 00c73021 8e080010 8e090000 
	8e070008 15000008 8e110090 00809821 00601021 00a0a021 00c09021 00a0b021 
	1000001a 0080a821 240a0001 150a000c 240a0002 00031827 00699821 00041027 
	00491021 00063027 00c7a021 00059027 02479021 0240b021 10000016 0040a821 
	550a000b 24090003 01263023 24d3ffff 00051027 00491021 0080a021 00609021 
	0080b021 1000000b 0040a821 24090003 15090008 00031827 00a09821 00c01021 
	0067a021 00049027 02479021 0240b021 00a0a821 24040036 00402821 02003021 
	0411FF1C 00000000 24040037 02602821 02003021 0411FF17 00000000 24040038 
	02402821 02003021 0411FF12 00000000 24040039 02802821 02003021 0411FF0D 
	00000000 24040020 02a02821 02003021 0411FF08 00000000 24040021 02c02821 
	02003021 0411FF03 00000000 8e220004 8e230008 ac430000 24040022 02002821 
	0411FE82 00000000 8e220000 8e230008 ac430000 8fbf002c 8fb60028 8fb50024 
	8fb40020 8fb3001c 8fb20018 8fb10014 8fb00010 03e00008 27bd0030 

	'localfastfillrect
	27bdffc8 afbf0034 afb60030 afb5002c afb40028 afb30024 afb20020 afb1001c 
	afb00018 00808021 8fa20048 8fb2004c 8e430090 8c750010 8c74000c 8c730014 
	7047b002 afb20010 00a02021 00c02821 00e03021 00403821 0411FF7A 00000000 
	7e0220c0 00108a03 3231f800 00518825 00108143 321007e0 02308825 00111a02 
	322200ff 1062000d 02202021 12c00019 26d0ffff 2413ffff 02202021 02402821 
	0411FE4B 00000000 2610ffff 1613fffb 02202021 10000010 8fbf0034 02402821 
	0411FE43 00000000 26d6ffff 12c00009 26d6ffff 2402ffff aeb30000 ae930000 
	aeb30000 ae930000 26d6ffff 16c2fffa 00000000 8fbf0034 8fb60030 8fb5002c 
	8fb40028 8fb30024 8fb20020 8fb1001c 8fb00018 03e00008 27bd0038 

	'pixel
	27bdffd8 afbf0024 afb10020 afb0001c 00808021 00e08821 afa70010 00a02021 
	00c02821 24060001 24070001 0411FF3E 00000000 7e0220c0 00102203 3084f800 
	00442025 00108143 321007e0 00902025 02202821 0411FE17 00000000 8fbf0024 
	8fb10020 8fb0001c 03e00008 27bd0028 

	'scroll
	27bdff98 afbf0064 afbe0060 afb7005c afb60058 afb50054 afb40050 afb3004c 
	afb20048 afb10044 afb00040 00809821 afa5006c afa70074 8fb70078 24a2ffff 
	00471021 afa20018 2482ffff 00461021 afa20034 00008821 8ef40090 02808021 
	8ef500a0 3c129d00 8e420028 0040f809 8ee40088 24030001 00431804 afa3002c 
	8e420024 8ee40088 0040f809 24050005 afa2001c 8e420024 8ee40088 0040f809 
	24050006 afa20020 26730001 afb30028 8fa30034 0073102a 14400088 8fa40074 
	00042040 afa40024 26850064 afa50030 26940084 8fb6002c 3c1ebf81 8fa2006c 
	8fa30018 0043102a afa20038 afb70010 8fa40028 8fa5006c 24060001 8fa70074 
	0411FEED 00000000 8fa30030 00601021 8c440000 8c45ffc0 ac850000 24420004 
	5454fffc 8c440000 8fa5002c 8fa4001c ac850000 8fc2f220 8fa20020 ac450000 
	8fc2f220 ac850000 8fc2f220 8fa40020 ac850000 8fc2f220 00002021 8fa5001c 
	acb60000 8fc2f220 8fa20020 ac560000 8e020084 8c450000 8e020024 00a21024 
	0002102b 8e050088 8ca60000 8e050028 00c53024 34450002 00a6100b 8e05008c 
	8ca60000 8e05002c 00c53024 34450004 00a6100b 8e050090 8ca60000 8e050030 
	00c53024 34450008 00a6100b 8e050094 8ca60000 8e050034 00c53024 34450010 
	00a6100b 8e050098 8ca60000 8e050038 00c53024 34450020 00a6100b 8e05009c 
	8ca60000 8e05003c 00c53024 34450040 00a6100b 8e0500a0 8ca60000 8e050040 
	00c53024 34450080 00a6100b 00952821 a0a20000 24840001 8fa50024 0085102a 
	1440ffc6 02a09021 8c620000 8c64ffc0 ac440000 24630004 5683fffc 8c620000 
	afb70010 8fa20028 2444ffff 8fa5006c 24060001 8fa70074 0411FE8F 00000000 
	8fa30038 1060000f 8fa50028 8fb3006c 92420000 7c517a04 92420001 7c513804 
	02202021 02e02821 0411FD66 00000000 26730001 8fa40018 1664fff5 26520002 
	8fa50028 24a50001 afa50028 8fa30034 0065102a 5040ff86 afb70010 8fbf0064 
	8fbe0060 8fb7005c 8fb60058 8fb50054 8fb40050 8fb3004c 8fb20048 8fb10044 
	8fb00040 03e00008 27bd0068 

	'DBitmap
	27bdff88 afbf0074 afbe0070 afb7006c afb60068 afb50064 afb40060 afb3005c 
	afb20058 afb10054 afb00050 afa40078 00a08021 afa60080 afa70084 8fb20088 
	8fa3008c 8fa50098 8ca40010 2c840002 10800005 8fa20090 8cb30000 8ca40008 
	10000004 afa40034 8cb30008 8ca40000 afa40034 7c6520c0 00032203 3084f800 
	00a42025 00031943 306307e0 00831825 afa30028 7c4420c0 00021a03 3063f800 
	00831825 00021143 304207e0 00621025 afa2002c 8fa50098 afa50010 8fa40078 
	02002821 8fa20080 72423002 8fa20084 72423802 0411FE35 00000000 8fa30084 
	18600068 8fbf0074 afb20020 afb00038 8fa40080 afa40044 00042823 afa50048 
	00640018 00001012 afa20040 afa0001c 10000058 afa0003c 06000015 0213102b 
	50400014 26310001 06a20012 26310001 52e00010 26310001 93c20000 8fa30018 
	00431024 10400007 8fa4002c 8fa40028 8fa50098 0411FCF8 00000000 10000005 
	26310001 8fa50098 0411FCF3 00000000 26310001 1632ffe8 26100001 26940001 
	8fa40020 8fa50080 12850016 02c4b021 8fa3001c 02831021 24430007 285e0000 
	007e100b 0002f0c3 8fa40094 009ef021 8fa50024 00b41823 000317c3 00021742 
	00621821 30630007 00621023 24030001 00431004 afa20018 02c08021 1000ffce 
	00008821 8fa40030 24840001 afa40030 14920007 26b50001 1000000c 8fa4003c 
	afa00030 8fa50040 24a5ffff afa50024 8fa20080 1840fff3 8fb60078 0000a021 
	8fa30034 1000ffda 02a3b82b 24840001 afa4003c 8fa50038 8fa20020 00a22821 
	afa50038 8fa3001c 8fa40044 00641821 afa3001c 8fa50040 8fa20048 00a22821 
	afa50040 8fa3003c 8fa40084 10640005 8fbf0074 1e40ffe2 8fb50038 1000ffeb 
	8fa4003c 8fbe0070 8fb7006c 8fb60068 8fb50064 8fb40060 8fb3005c 8fb20058 
	8fb10054 8fb00050 03e00008 27bd0078 

	'swap
	8c820000 8ca30000 ac830000 03e00008 aca20000 

	'drawline
	27bdffc8 afbf0034 afb60030 afb5002c afb40028 afb30024 afb20020 afb1001c 
	afb00018 00809821 afa5003c afa60040 afa70044 8fa20048 14c20016 8fb4004c 
	00e5102a 10400006 8fa2003c 27a4003c 27a50044 0411FFE5 00000000 8fa2003c 
	8fa70044 24e70001 24030001 afa30010 afb40014 02602021 00402821 8fa60040 
	00e23823 0411FE07 00000000 10000046 8fbf0034 8fb5003c 8fa30044 16a30015 
	00759023 0046102a 10400006 8fa60040 27a40040 27a50048 0411FFCC 00000000 
	8fa60040 8fa20048 24420001 00461023 afa20010 afb40014 02602021 8fa5003c 
	24070001 0411FDEF 00000000 1000002e 8fbf0034 001227c3 00929026 02449023 
	02a3a82a 24040001 2405ffff 00b5200a 0080a821 00468823 00111fc3 00718826 
	00718823 00c2b02a 24030001 2404ffff 0096180a 0060b021 02328021 02602021 
	8fa5003c 8fa60040 02803821 0411FE1C 00000000 00101040 0051182a 54600008 
	0242102a 8fa3003c 8fa40044 1064000d 02118021 02a31821 afa3003c 0242102a 
	1440ffef 02602021 8fa20040 8fa30048 10430004 02128021 02c21021 1000ffe8 
	afa20040 8fbf0034 8fb60030 8fb5002c 8fb40028 8fb30024 8fb20020 8fb1001c 
	8fb00018 03e00008 27bd0038 

	'drawchar
	27bdffd0 afbf002c 8faa0040 8fa90044 8fa20048 8fab004c 7c042420 3c039d00 
	8c630054 00052880 00a31821 8c650000 90a80001 90ac0002 008c682a 15a00019 
	90a30000 90ad0003 01ac6821 008d682a 51a00015 71024002 afa20010 afa60014 
	afa70018 71031002 000210c3 008c6023 704c2002 24840004 00a42821 afa5001c 
	afab0020 01402021 01202821 00603021 01003821 0411FEB6 00000000 1000000b 
	8fbf002c 71024002 afa80010 afab0014 00e02021 01402821 01203021 70623802 
	0411FD85 00000000 8fbf002c 03e00008 27bd0030 

	'testchar
	8fa30010 8c680010 8c690000 70e61002 00442021 2d020002 10400009 8c630008 
	04800012 00001021 04a00010 0124302a 14c0000e 0065302a 14c0000c 00000000 
	2508fffe 2d080002 11000008 24020001 04800006 00001021 04a00004 0064182a 
	14600002 0125282a 38a20001 03e00008 00000000 

	'pstring
	27bdffb8 afbf0044 afbe0040 afb7003c afb60038 afb50034 afb40030 afb3002c 
	afb20028 afb10024 afb00020 0080b821 00a08021 00c09821 00e0a021 8fb50064 
	3c029d00 8c420054 00041880 00621021 8c420000 90560000 92a20000 1840001b 
	8fb20060 72c7f002 24110001 afb20010 02002021 02602821 02803021 02c03821 
	0411FFC2 00000000 10400016 02b11021 80440000 afb00010 afb30014 afb40018 
	afb2001c 02e02821 8fa60058 8fa7005c 0411FF81 00000000 26310001 92a20000 
	0051102a 1040ffe9 021e8021 ae500020 001087c3 ae500024 ae530028 00139fc3 
	ae53002c 8fbf0044 8fbe0040 8fb7003c 8fb60038 8fb50034 8fb40030 8fb3002c 
	8fb20028 8fb10024 8fb00020 03e00008 27bd0048 

	'dcirch
	27bdffb8 afbf0044 afbe0040 afb7003c afb60038 afb50034 afb40030 afb3002c 
	afb20028 afb10024 afb00020 0080a821 00a0a021 00c09821 00e08821 8fa30058 
	30620010 10400017 8fb6005c 00e63021 02c03821 0411FD50 00000000 02a02021 
	02802821 02713023 02c03821 0411FD4A 00000000 02a02021 02342821 02603021 
	02c03821 0411FD44 00000000 02a02021 02912823 02603021 02c03821 0411FD3E 
	00000000 1a200054 24120001 02519023 0011b823 0017b840 00008021 8fa20058 
	305e0004 30430002 afa30014 30420008 afa20018 8fa30058 30630001 afa30010 
	06400004 00000000 2631ffff 26f70002 02579021 13c0000d 26100001 02a02021 
	02142821 02333021 02c03821 0411FD22 00000000 02a02021 02342821 02133021 
	02c03821 0411FD1C 00000000 8fa20014 1040000e 8fa30018 02a02021 02142821 
	02713023 02c03821 0411FD13 00000000 02a02021 02342821 02703023 02c03821 
	0411FD0D 00000000 8fa30018 1060000e 8fa20010 02a02021 02912823 02133021 
	02c03821 0411FD04 00000000 02a02021 02902823 02333021 02c03821 0411FCFE 
	00000000 8fa20010 1040000e 0211102a 02a02021 02912823 02703023 02c03821 
	0411FCF5 00000000 02a02021 02902823 02713023 02c03821 0411FCEF 00000000 
	0211102a 10400004 00101040 24420001 1000ffbb 02429021 8fbf0044 8fbe0040 
	8fb7003c 8fb60038 8fb50034 8fb40030 8fb3002c 8fb20028 8fb10024 8fb00020 
	03e00008 27bd0048 

	'fcirch
	27bdffb0 afbf004c afbe0048 afb70044 afb60040 afb5003c afb40038 afb30034 
	afb20030 afb1002c afb00028 0080b821 00a0b021 8fb50068 18c00048 8fbe0070 
	24100001 02068023 0006a023 0014a040 00c08821 24130003 00009021 30e20001 
	afa20018 8fa30060 24630001 afa30020 30e70002 afa7001c 06000004 8fa20018 
	2631ffff 26940002 02148021 10400016 26520001 00111040 8fa30020 00621021 
	afa20010 afbe0014 02a02021 02572821 02d13023 24070001 0411FC66 00000000 
	8fa30060 02631021 afa20010 afbe0014 02a02021 02372821 02d23023 24070001 
	0411FC5C 00000000 8fa2001c 10400017 0251102a 00111040 8fa30020 00621021 
	afa20010 afbe0014 02a02021 02f22823 02d13023 24070001 0411FC4E 00000000 
	8fa30060 02631021 afa20010 afbe0014 02a02021 02f12823 02d23023 24070001 
	0411FC44 00000000 0251102a 10400003 02138021 1000ffc8 26730002 8fbf004c 
	8fbe0048 8fb70044 8fb60040 8fb5003c 8fb40038 8fb30034 8fb20030 8fb1002c 
	8fb00028 03e00008 27bd0050 

	'ftri
	27bdff90 afbf006c afbe0068 afb70064 afb60060 afb5005c afb40058 afb30054 
	afb20050 afb1004c afb00048 afa40070 188000df 8fb20090 00a0a821 00c0b021 
	00e0b821 8fbe0080 8fa20084 afa20038 8fa30088 afa3003c 8fa4008c afa40040 
	afa00044 8ea20000 afa20020 8ec30000 afa30024 8ee20000 afa20028 8fc20000 
	afa2002c 8fa50038 8ca40000 afa40030 8fa5003c 8ca40000 afa40034 8fa40040 
	0043102a 10400009 8c910000 27a40024 27a5002c 0411FDD6 00000000 27a40020 
	27a50028 0411FDD2 00000000 8fa20034 8fa3002c 0043102a 1040000a 8fa2002c 
	27a40034 27a5002c 0411FDC9 00000000 27a40030 27a50028 0411FDC5 00000000 
	8fa2002c 8fa30024 0043102a 1040000a 8fb00024 27a40024 27a5002c 0411FDBC 
	00000000 27a40020 27a50028 0411FDB8 00000000 8fb00024 8fa20034 16020023 
	8fb3002c 8fa20020 afa20018 afa2001c 8fa30028 0062202a 10800003 0043102a 
	10000003 afa30018 54400001 afa3001c 8fa20030 8fa30018 0043182a 10600003 
	8fa3001c 10000004 afa20018 0062182a 54600001 afa2001c 8fa50018 8fa2001c 
	24420001 00451023 afa20010 afb20014 02202021 8fa60024 24070001 0411FBC2 
	00000000 10000069 8fa20044 00531026 0002102b 02629823 0270102a 14400030 
	8fa20034 24140001 8fa20020 8fa30024 02032823 8fa60028 00c23023 70a63002 
	8fa4002c 00832023 00c4001a 008001f4 00002012 00822021 afa40018 8fa60030 
	00c23023 70a62802 8fa60034 00c31823 00a3001a 006001f4 00001812 00621021 
	afa2001c 0044102a 10400006 8fa20018 27a40018 27a5001c 0411FD6D 00000000 
	8fa20018 8fa7001c 24e70001 afb40010 afb20014 02202021 00402821 02003021 
	00e23823 0411FB90 00000000 26100001 0270102a 1040ffd5 8fa20020 8fa20034 
	0050182a 54600031 8fa20044 24130001 8fa60028 8fa40020 8fa50030 8fa8002c 
	02083823 00a61823 70e33802 00484023 00e8001a 010001f4 00001812 00661821 
	afa30018 8fa70024 02073023 00a42823 70c53002 00471023 00c2001a 004001f4 
	00001012 00442021 afa4001c 0083202a 10800006 8fa20018 27a40018 27a5001c 
	0411FD3B 00000000 8fa20018 8fa7001c 24e70001 afb30010 afb20014 02202021 
	00402821 02003021 00e23823 0411FB5E 00000000 26100001 8fa20034 0050182a 
	1060ffd4 8fa60028 8fa20044 24420001 afa20044 26b50008 26d60008 26f70008 
	8fa30038 24630008 afa30038 8fa4003c 24840008 afa4003c 8fa50040 24a50008 
	afa50040 8fa30070 1443ff2e 27de0008 8fbf006c 8fbe0068 8fb70064 8fb60060 
	8fb5005c 8fb40058 8fb30054 8fb20050 8fb1004c 8fb00048 03e00008 27bd0070 

	'main
	27bdffd0 afbf002c 8fa20040 8fa30044 8fa80048 8fa9004c 8faa0050 8c840000 
	1480000a 8fab0054 8ca40000 8cc50000 8ce60000 00403821 0411FB72 00000000 
	00002021 1000008f 00002821 240c0001 148c000d 240c0002 8ca40000 8cc50000 
	8ce60000 8c470000 8c620000 afa20010 afa80014 0411FB1C 00000000 00002021 
	10000080 00002821 148c000f 240c0003 8ca40000 afa30010 afa80014 afa90018 
	afaa001c afab0020 00c02821 00e03021 00403821 0411FEDA 00000000 00002021 
	10000070 00002821 148c000d 240c0005 8ca40000 8cc50000 8ce60000 8c470000 
	8c620000 afa20010 afa80014 0411FCD5 00000000 00002021 10000062 00002821 
	148c0009 240c0007 8ca40000 8cc50000 00e03021 0411F9E2 00000000 00002021 
	10000058 00002821 148c0010 240c0008 8ca40000 8cc50000 8ce60000 8c470000 
	8c620000 afa20010 8d020000 afa20014 afa90018 afaa001c 0411FD7F 00000000 
	00002021 10000047 00002821 148c0011 240c0009 8ca40000 8cc50000 8ce60000 
	8c470000 8c620000 afa20010 8d020000 afa20018 000217c3 afa2001c afa90020 
	0411FE3C 00000000 00002021 10000035 00002821 148c000d 240c000a 8ca40000 
	8cc50000 8ce60000 8c470000 8c620000 afa20010 afa80014 0411FDA4 00000000 
	00002021 10000027 00002821 548c0012 2408000b 8ca40000 8cc50000 8ce60000 
	8c470000 8c620000 afa20010 8d020000 afa20014 8d220000 afa20018 afaa001c 
	afab0020 0411FBD6 00000000 00002021 10000014 00002821 5488000b 2402000c 
	8ca40000 8cc50000 8ce60000 8c470000 afa30010 0411FB07 00000000 00002021 
	10000008 00002821 14820009 8fbf002c 00a02021 0411F9A5 00000000 00402021 
	00002821 00801021 00a01821 8fbf002c 03e00008 27bd0030 
End CFunction   'MIPS32 M4K
'
'******************************************************************************

'----------------------------------------------------------------------------
	'Cut here and throw away below when using the Library in your own program
testsuite:
'      
  dim integer maxgauges=1
  dim integer x(maxgauges), y(maxgauges), radius(maxgauges), fontsize(maxgauges)
  dim integer lastx1(maxgauges), lastx2(maxgauges), lastx3(maxgauges), lasty1(maxgauges), lasty2(maxgauges), lasty3(maxgauges) 
  dim integer whitesec(maxgauges),greensec(maxgauges),yellowsec(maxgauges),redsec(maxgauges),blacksec(maxgauges)
'
' Define the pins to use for all connections to the display
'
	PRINT "start Init"
	
	'Tell the library which pins we're using for the display
	'Connect CS to GND
	'SUB S6D8.PinDefs(D0,D1,D2,D3,D4,D5,D6,D7,RS,RD,WR,RST)
	S6D8.PinDefs(25,26,27,36,37,38,2,3,12,13,23,32)
	S6D8.init 'initialise the S6D8 display

	PRINT "Start main"

	DO
	   S6D8TestSuite
	LOOP

END
sub S6D8TestSuite
  local integer i, j, x0, y0, x1, y1, sz, bitmap(1)=(&HFFC1A191898583FF,0)
  LOCAL INTEGER xp=40, rp=60, yp=80, bp=100, wp=120, cp=140, zp=160
  dim s$ length 10
  LOCAL FLOAT tn
  CONST scrollxstart=18, scrollxwidth=140,newpoint=scrollxstart+scrollxwidth-1
  CONST scrollystart=20,scrollyheight=180, scrolldirection=0
  S6D8.ROTATE(portrait)
  S6D8.CLS()
  S6D8.BOX(0, 0,S6D8.MM.HRES,S6D8.MM.VRES,rgb(red))
  for i=10 to 0 step -1
    S6D8.TEXT(S6D8.MM.HRES/2-48, 70, str$(i,2) ,1 ,2, rgb(green))
    pause 500
  next i
  S6D8.TEXT(S6D8.MM.HRES/2-48, 70, "  " ,1 ,2, rgb(green))
  for i=0 to 3
     S6D8.ROTATE(i)
     S6D8.BITMAP(2,2,bitmap(),8,8,2,rgb(cyan))
  next i
  S6D8.ROTATE(rlandscape)
  S6D8.TEXT(S6D8.MM.HRES/2-56, 30, "Welcome to the", 0,1, rgb(green))
  S6D8.TEXT(S6D8.MM.HRES/2-60, 70,  "Micromite MKII", 0,1, rgb(red))
  S6D8.TEXT(S6D8.MM.HRES/2-40, 100, "in colour", 0,1, rgb(yellow))
  S6D8.TEXT(S6D8.MM.HRES/2-80, 120,  "8-bit parallel S6D0164", 0,1, rgb(cyan))
  pause 4000

' demo fast line draw
  S6D8.CLS()
  S6D8.ROTATE(portrait)
  x0=0:y0=0:y1=S6D8.MM.VRES-1
  for i=0 to 44 step 2
    tn=tan(rad(i))
    x1=S6D8.MM.HRES*tn
    S6D8.LINE(x0, y0, x1, y1, rgb(red))
  next i
  x1=S6D8.MM.HRES-1
  for i=0 to 44 step 2
    tn=tan(rad(i))
    y1=S6D8.MM.VRES*tn
    S6D8.LINE(x0, y0, x1, y1, rgb(red))
  next i
  S6D8.BOX(0, 0, S6D8.MM.HRES, S6D8.MM.VRES, rgb(blue))
  pause 2000

  S6D8.CLS()
'demo fast text write
  S6D8.ROTATE(LANDSCAPE)

  for i=0 to S6D8.MM.VRES-13 step 13
    S6D8.TEXT(0, i, "Hello world:Bye world:Hello world:Bye world:Hello world:Bye world:Hello world:Bye world", 0,1, rgb(white))
  next i
  pause 2000
  S6D8.ROTATE(RLANDSCAPE)
  S6D8.CLS()
  for i=0 to S6D8.MM.VRES-26 step 26
    S6D8.TEXT(0, i, "Micromite MK2:Invert:Micromite MK2:Invert", 0,2, rgb(red))
  next i
  pause 2000
  S6D8.ROTATE(RPORTRAIT)
  S6D8.CLS()
  for i=0 to S6D8.MM.VRES-39 step 39
    S6D8.TEXT(0,i, "Rotate right:Rotate right:Rotate right", 0,3, rgb(yellow))
  next i
  pause 2000
  S6D8.ROTATE(PORTRAIT)
  S6D8.CLS()
  for i=0 to S6D8.MM.VRES-52 step 52
    S6D8.TEXT(0,i, "Rotate Left:Rotate Left:Rotate Left", 0,3, rgb(blue))
  next i
  pause 2000
  S6D8.CLS()
  ' test drawing rectangles
  for i=0 to 3
     S6D8.ROTATE(i)
     S6D8.BOX(5, 5, 60, 50, rgb(white), rgb(blue))
     S6D8.BOX(2, 2, 66, 56, rgb(red))
  next i
  pause 2000
' test drawing rounded rectangles
  S6D8.CLS()
  for i=0 to 3
     S6D8.ROTATE(i)
     S6D8.RBOX(5, 5, 80, 45, 10, rgb(blue), rgb(blue))
     S6D8.RBOX(2, 2, 86, 51, 12, rgb(red))
  next i
  pause 2000
  S6D8.CLS()
' test drawing circles
  for i=0 to 3
     S6D8.ROTATE(i)
     S6D8.CIRCLE(40, 40, 35, rgb(blue), rgb(blue))
     S6D8.CIRCLE(40, 40, 39, rgb(red))
  next i
  pause 2000
' test drawing triangles and line drawing
  S6D8.CLS()
  for i=0 to 3
     S6D8.ROTATE(i)
     S6D8.TRIANGLE(4, 4, 70, 6, 22, 74, rgb(blue), rgb(blue))
     S6D8.TRIANGLE(1, 2, 74, 4, 22, 77, rgb(red))
  next i
  pause 2000
  S6D8.ROTATE(PORTRAIT)
  S6D8.CLS()
  S6D8.BOX(scrollxstart-1,scrollystart-1,scrollxwidth+2,scrollyheight+2,rgb(red))
  S6D8.TEXT(scrollxstart,0,"Micromite MKII 4.7",0,1,rgb(white))
  S6D8.TEXT(scrollxstart,scrollystart+scrollyheight+5,"Demo of scrolling",0,1,rgb(white))
  S6D8.ROTATE(LANDSCAPE)
  S6D8.TEXT(40,0,"S6D0164 controller",0,1,rgb(white))
  S6D8.TEXT(40,S6D8.MM.VRES-14,"S6D0164 controller",0,1,rgb(white))
  S6D8.ROTATE(PORTRAIT)
 TIMER=0
 DO
   S6D8.SCROLL(scrollxstart,scrollystart,scrollxwidth,scrollyheight)
   S6D8.PIXEL(newpoint,xp) ' clear the old data after the scroll
   S6D8.PIXEL(newpoint,rp)
   S6D8.PIXEL(newpoint,yp)
  S6D8.PIXEL(newpoint,bp)
   S6D8.PIXEL(newpoint,wp)
   S6D8.PIXEL(newpoint,cp)
   S6D8.PIXEL(newpoint,zp)
   rp=rp+(RND()*2)-1 'get the new data points
   bp=bp+(RND()*2)-1
   yp=yp+(RND()*2)-1
   xp=xp+(RND()*2)-1
   zp=zp+(RND()*2)-1
   wp=wp+(RND()*2)-1
   cp=cp+(RND()*2)-1
   if xp>=scrollystart and xp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,xp,rgb(yellow)) 'write them to the space left
   if rp>=scrollystart and rp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,rp,rgb(blue))
   if yp>=scrollystart and yp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,yp,rgb(red))
   if bp>=scrollystart and bp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,bp,rgb(green))
   if wp>=scrollystart and wp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,wp,rgb(magenta))
   if cp>=scrollystart and cp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,cp,rgb(cyan))
   if zp>=scrollystart and zp< scrollyheight+scrollystart then S6D8.PIXEL(newpoint,zp,rgb(white))
LOOP UNTIL TIMER>40000
S6D8.CLS()
initgauge(0,S6D8.mm.hres\2,S6D8.mm.vres\2,S6D8.mm.hres\2-5,1,-150,-100,0,75,150,"EGT")
timer=0
do ' run the pointer backwards and forwards
    i=rnd(22)* (blacksec(j)-whitesec(j)) + whitesec(j)
    s$=str$(i+400,4)
    needle(j,i,rgb(white),s$)
    pause 500
LOOP UNTIL TIMER>40000
'
end SUB
'
' Routine to draw a segment of a circle
' Parameters are:
' x-coordinate of centre of circle
' y-coordinate of centre of circle
' radius of circle
' start radial of segment to be drawn (0-360 degrees)
' end radial of segment to be drawn (0-360 degrees)
' colour to draw segment
'
' NB if start radial and end radial are the same a line will be drawn
'
Sub segment(x As integer, y As integer, size As integer, startradial As integer, endradial As integer, col As integer)
  Local integer i,j,x1,x2,y1,y2,sr,er
  If startradial=endradial Then
      x2=Sin(Rad(startradial))*size + x
      y2=-Cos(Rad(startradial))*size + y
      s6d8.Line(x,y,x2,y2,col)
  Else
    If startradial<endradial Then
      sr=startradial
      er=endradial
    Else
      er=startradial
      sr=endradial
    EndIf
    Local integer xx0(er-sr),yy0(er-sr),xx1(er-sr),yy1(er-sr),xx2(er-sr),yy2(er-sr),tcol(er-sr)
    j=0
    For i=sr+1 To er
      xx0(j)=x: yy0(j)=y
      xx2(j)=Sin(Rad(i))*size + x
      yy2(j)=-Cos(Rad(i))*size + y
      xx1(j)=Sin(Rad(i-1))*size + x
      yy1(j)=-Cos(Rad(i-1))*size + y
      tcol(j)=col
      j=j+1
    Next i
    i=S6D8(S6D8.filltri, j, xx0(),yy0(),xx1(),yy1(),xx2(),yy2(),tcol(),S6D8.VAR()) 
  EndIf
End Sub
'
' Routine to initialise a gauge
' Parameters are:
' gaugeindex
' x-coordinate of centre of gauge
' y-coordinate of centre of gauge
' radius of gauge
' font size
' start radial of white segment (-180 to 180)
' start radial of green segment (-180 to 180, must be greater or equal to start of previous segment)
' start radial of yellow segment (-180 to 180, must be greater or equal to start of previous segment)
' start radial of red segment (-180 to 180, must be greater or equal to start of previous segment)
' start radial of black segment (-180 to 180, must be greater or equal to start of previous segment)
' string to display as gauge title
'
sub initgauge(gaugeindex% , xpos%, ypos%, gsize%, fontmult%, whitestart%, greenstart%, yellowstart%, redstart%, blackstart%, displaystring$)
  S6D8.circle(xpos%,ypos%,gsize%+3,RGB(210,210,210),RGB(210,210,210)) 'background to create the bezel
  segment(xpos%,ypos%,gsize%,whitestart%,greenstart%, RGB(white))
  segment(xpos%,ypos%,gsize%,greenstart%,greenstart%, S6D8.black())
  segment(xpos%,ypos%,gsize%,greenstart%,yellowstart%, RGB(green))
  segment(xpos%,ypos%,gsize%,yellowstart%,redstart%, RGB(yellow))
  segment(xpos%,ypos%,gsize%,redstart%,blackstart%, RGB(red))
  segment(xpos%,ypos%,gsize%,blackstart%,whitestart%+360, S6D8.black())
  segment(xpos%,ypos%,gsize%,greenstart%,greenstart%, S6D8.black())
  segment(xpos%,ypos%,gsize%,yellowstart%,yellowstart%, S6D8.black())
  segment(xpos%,ypos%,gsize%,redstart%,redstart%, S6D8.black())
  s6d8.Circle(xpos%,ypos%,gsize%\5*4,S6D8.black(),S6D8.black())
  s6d8.text(xpos%-len(displaystring$)*4*fontmult%,ypos%+gsize%-fontmult%*28,displaystring$,0,fontmult%,rgb(white),0) ' string centred in black segment
  x(gaugeindex%)=xpos%
  y(gaugeindex%)=ypos%
  radius(gaugeindex%)=gsize%
  fontsize(gaugeindex%)=fontmult%
  lastx1(gaugeindex%)=xpos%
  lastx2(gaugeindex%)=xpos%+2
  lastx3(gaugeindex%)=xpos%+2
  lasty1(gaugeindex%)=ypos%
  lasty2(gaugeindex%)=ypos%+2
  lasty3(gaugeindex%)=ypos%
  whitesec(gaugeindex%)=whitestart%
  greensec(gaugeindex%)=greenstart%
  yellowsec(gaugeindex%)=yellowstart%
  redsec(gaugeindex%)=redstart%
  blacksec(gaugeindex%)=blackstart%
end sub
'
'
' Routine to draw a pointer
' Parameters are:
' gaugeindex
' radial of pointer to be drawn (0-360 degrees)
' colour to draw pointer
'
Sub needle(gaugeindex as integer, angle As integer, col As integer, value$ as string)
Local integer x1,y1,x2,y2,x3,y3,x4,y4,j, xx1(1),yy1(1),xx2(1),yy2(1),xx3(1),yy3(1), tcol(1), size
    size= radius(gaugeindex)\5*4-1
    x1=Sin(Rad(angle-90))*size/10 + x(gaugeindex)
    y1=-Cos(Rad(angle-90))*size/10 + y(gaugeindex)
    x2=Sin(Rad(angle))*size + x(gaugeindex)
    y2=-Cos(Rad(angle))*size + y(gaugeindex)
    x3=Sin(Rad(angle+90))*size/10 + x(gaugeindex)
    y3=-Cos(Rad(angle+90))*size/10 + y(gaugeindex)
    xx1(0)=lastx1(gaugeindex)
    yy1(0)=lasty1(gaugeindex)
    xx2(0)=lastx2(gaugeindex)
    yy2(0)=lasty2(gaugeindex)
    xx3(0)=lastx3(gaugeindex)
    yy3(0)=lasty3(gaugeindex)
    xx1(1)=x1
    yy1(1)=y1
    xx2(1)=x2
    yy2(1)=y2
    xx3(1)=x3
    yy3(1)=y3
    tcol(0)=0
    tcol(1)=col
    j=S6D8(S6D8.filltri, 2,xx1(),yy1(),xx2(),yy2(),xx3(),yy3(),tcol(),S6D8.VAR())
    S6D8.Circle(x(gaugeindex),y(gaugeindex),size\10,col,col))
    S6D8.Circle(x(gaugeindex),y(gaugeindex),size\15,S6D8.black(),S6D8.black())
    S6D8.Circle(x(gaugeindex),y(gaugeindex),size\20,RGB(240,240,240),RGB(240,240,240))
    lastx1(gaugeindex)=x1
    lastx2(gaugeindex)=x2
    lastx3(gaugeindex)=x3
    lasty1(gaugeindex)=y1
    lasty2(gaugeindex)=y2
    lasty3(gaugeindex)=y3
    S6D8.text(x(gaugeindex)-len(value$)*4*fontsize(gaugeindex)-3*fontsize(gaugeindex),y(gaugeindex)+radius(gaugeindex)-fontsize(gaugeindex)*16,value$,0,fontsize(gaugeindex),col,0) ' string centred in black segment
End Sub
